<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package EnterpriseUp
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<?php wp_body_open(); ?>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#primary"><?php esc_html_e( 'Skip to content', 'enterpriseup' ); ?></a>
	<header id="masthead" class="site-header">
		<div class="top-header-part">
			<div class="ascendoor-wrapper">
				<div class="top-header-part-wrapper">
					<div class="top-header-left-part">
						<div class="site-branding">
							<?php if ( has_custom_logo() ) { ?>
								<div class="site-logo">
									<?php the_custom_logo(); ?>
								</div>
							<?php } ?>
							<div class="site-identity">
								<?php
								if ( is_front_page() && is_home() ) :
									?>
									<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
									<?php
								else :
									?>
									<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
									<?php
								endif;
								$enterpriseup_description = get_bloginfo( 'description', 'display' );
								if ( $enterpriseup_description || is_customize_preview() ) :
									?>
									<p class="site-description"><?php echo $enterpriseup_description; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></p>
									<?php
								endif;
								?>
							</div>
						</div><!-- .site-branding -->
					</div>
					<div class="top-header-right-part">
						<div class="top-header-contact">
							<?php
							$contact_label  = get_theme_mod( 'enterpriseup_contact_label' );
							$contact_number = get_theme_mod( 'enterpriseup_contact_number' );
							$email_label    = get_theme_mod( 'enterpriseup_email_label' );
							$email_address  = get_theme_mod( 'enterpriseup_email_address' );
							$social_label   = get_theme_mod( 'enterpriseup_social_menu_label' );
							if ( ! empty( $contact_label ) || ! empty( $contact_number ) ) {
								?>
								<div class="header-contact-inner">
									<span class="contact-head contact-label">
										<h3><?php echo esc_html( $contact_label ); ?></h3>
									</span>
										<span class="contact-details">
											<i class="fas fa-phone-alt"></i>
										<span class="contact-number">
											<a href="tel:<?php echo esc_attr( $contact_number ); ?>"><?php echo esc_html( $contact_number ); ?></a>
										</span>
									</span>
								</div>
								<?php
							}
							if ( ! empty( $email_label ) || ! empty( $email_address ) ) {
								?>
								<div class="header-contact-inner">
									<span class="contact-head email-label">
										<h3><?php echo esc_html( $email_label ); ?></h3>
									</span>
									<span class="contact-details">
										<i class="fas fa-envelope"></i>
										<span class="email-address">
											<a href="mailto:<?php echo esc_attr( $email_address ); ?>"><?php echo esc_html( $email_address ); ?></a>
										</span>
									</span>
								</div>
								<?php
							}
							?>
						</div>
						<?php if ( get_theme_mod( 'enterpriseup_enable_social_menu', true ) ) { ?>
							<div class="social-icons-part">
								<div class="header-social-title">
									<h3><?php echo esc_html( $social_label ); ?></h3>
								</div>
								<?php
								if ( has_nav_menu( 'social' ) ) {
									wp_nav_menu(
										array(
											'menu_class'  => 'menu social-links',
											'link_before' => '<span class="screen-reader-text">',
											'link_after'  => '</span>',
											'theme_location' => 'social',
										)
									);
								}
								?>
							</div>
						<?php } ?>
					</div>
				</div>
			</div>
		</div>
		<div class="bottom-header-outer-wrapper">
			<div class="bottom-header-part">
				<div class="ascendoor-wrapper">
					<div class="bottom-header-part-wrapper">
						<div class="navigation-part">
							<nav id="site-navigation" class="main-navigation">
								<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
									<span></span>
									<span></span>
									<span></span>
								</button>
								<div class="main-navigation-links">
									<?php
									if ( has_nav_menu( 'primary' ) ) {
										wp_nav_menu(
											array(
												'theme_location' => 'primary',
											)
										);
									}
									?>
									<div class="top-header-right-part">
										<div class="top-header-contact">
											<?php
											$contact_label  = get_theme_mod( 'enterpriseup_contact_label' );
											$contact_number = get_theme_mod( 'enterpriseup_contact_number' );
											$email_label    = get_theme_mod( 'enterpriseup_email_label' );
											$email_address  = get_theme_mod( 'enterpriseup_email_address' );
											$social_label   = get_theme_mod( 'enterpriseup_social_menu_label' );
											if ( ! empty( $contact_label ) || ! empty( $contact_number ) ) {
												?>
												<div class="header-contact-inner">
													<span class="contact-head contact-label">
														<h3><?php echo esc_html( $contact_label ); ?></h3>
													</span>
														<span class="contact-details">
															<i class="fas fa-phone-alt"></i>
														<span class="contact-number">
															<a href="tel:<?php echo esc_attr( $contact_number ); ?>"><?php echo esc_html( $contact_number ); ?></a>
														</span>
													</span>
												</div>
												<?php
											}
											if ( ! empty( $email_label ) || ! empty( $email_address ) ) {
												?>
												<div class="header-contact-inner">
													<span class="contact-head email-label">
														<h3><?php echo esc_html( $email_label ); ?></h3>
													</span>
													<span class="contact-details">
														<i class="fas fa-envelope"></i>
														<span class="email-address">
															<a href="mailto:<?php echo esc_attr( $email_address ); ?>"><?php echo esc_html( $email_address ); ?></a>
														</span>
													</span>
												</div>
												<?php
											}
											?>
										</div>
										<?php if ( get_theme_mod( 'enterpriseup_enable_social_menu', true ) ) { ?>
											<div class="social-icons-part">
												<div class="header-social-title">
													<h3><?php echo esc_html( $social_label ); ?></h3>
												</div>
												<?php
												if ( has_nav_menu( 'social' ) ) {
													wp_nav_menu(
														array(
															'menu_class'  => 'menu social-links',
															'link_before' => '<span class="screen-reader-text">',
															'link_after'  => '</span>',
															'theme_location' => 'social',
														)
													);
												}
												?>
											</div>
										<?php } ?>
									</div>
								</div>
							</nav><!-- #site-navigation -->
						</div>
						<div class="cart-part">
							<?php if ( class_exists( 'WooCommerce' ) ) { ?>
								<div class="header-user">
									<a href="<?php echo esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) ); ?>" title="<?php esc_attr_e( 'Account', 'enterpriseup' ); ?>"></a>
								</div>
								<div class="header-cart">
									<?php enterpriseup_woocommerce_header_cart(); ?>
								</div>
							<?php } ?>
							<?php if ( get_theme_mod( 'enterpriseup_enable_search_form', true ) ) { ?>
								<div class="header-search">
									<div class="header-search-wrap">
										<a href="#" title="Search" class="header-search-icon">
											<i class="fa fa-search"></i>
										</a>
										<div class="header-search-form">
											<?php get_search_form(); ?>
										</div>
									</div>
								</div>
							<?php } ?>
						</div>
					</div>
				</div>
			</div>
		</div>
	</header><!-- #masthead -->

	<?php if ( ! is_front_page() || is_home() ) { ?>
		<div id="content" class="site-content ascendoor-wrapper">
			<div class="ascendoor-page">
	<?php } ?>
