<?php
/**
 * Blog Section
 *
 * @package EnterpriseUp
 */

$wp_customize->add_section(
	'enterpriseup_blog_section',
	array(
		'panel'    => 'enterpriseup_front_page_options',
		'title'    => esc_html__( 'Blog Section', 'enterpriseup' ),
		'priority' => 70,
	)
);

// Blog Section - Enable Section.
$wp_customize->add_setting(
	'enterpriseup_enable_blog_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'enterpriseup_sanitize_switch',
	)
);

$wp_customize->add_control(
	new EnterpriseUp_Toggle_Switch_Custom_Control(
		$wp_customize,
		'enterpriseup_enable_blog_section',
		array(
			'label'    => esc_html__( 'Enable Blog Section', 'enterpriseup' ),
			'section'  => 'enterpriseup_blog_section',
			'settings' => 'enterpriseup_enable_blog_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'enterpriseup_enable_blog_section',
		array(
			'selector' => '#enterpriseup_blog_section .section-link',
			'settings' => 'enterpriseup_enable_blog_section',
		)
	);
}

// Blog Section - Section Title.
$wp_customize->add_setting(
	'enterpriseup_blog_title',
	array(
		'default'           => __( 'Latest News', 'enterpriseup' ),
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'enterpriseup_blog_title',
	array(
		'label'           => esc_html__( 'Section Title', 'enterpriseup' ),
		'section'         => 'enterpriseup_blog_section',
		'settings'        => 'enterpriseup_blog_title',
		'type'            => 'text',
		'active_callback' => 'enterpriseup_is_blog_section_enabled',
	)
);

// Blog Section - Section Text.
$wp_customize->add_setting(
	'enterpriseup_blog_text',
	array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'enterpriseup_blog_text',
	array(
		'label'           => esc_html__( 'Section Text', 'enterpriseup' ),
		'section'         => 'enterpriseup_blog_section',
		'settings'        => 'enterpriseup_blog_text',
		'type'            => 'text',
		'active_callback' => 'enterpriseup_is_blog_section_enabled',
	)
);

// Blog Section - Number of Posts.
$wp_customize->add_setting(
	'enterpriseup_blog_count',
	array(
		'default'           => 6,
		'sanitize_callback' => 'enterpriseup_sanitize_number_range',
	)
);

$wp_customize->add_control(
	'enterpriseup_blog_count',
	array(
		'label'           => esc_html__( 'Number of Posts to Show', 'enterpriseup' ),
		'description'     => esc_html__( 'Note: Min 1 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'enterpriseup' ),
		'section'         => 'enterpriseup_blog_section',
		'settings'        => 'enterpriseup_blog_count',
		'type'            => 'number',
		'input_attrs'     => array(
			'min' => 1,
			'max' => 6,
		),
		'active_callback' => 'enterpriseup_is_blog_section_enabled',
	)
);

// Blog Section - Description Length.
$wp_customize->add_setting(
	'enterpriseup_blog_excerpt_count',
	array(
		'default'           => 20,
		'sanitize_callback' => 'absint',
	)
);

$wp_customize->add_control(
	'enterpriseup_blog_excerpt_count',
	array(
		'label'           => esc_html__( 'Description Length (words)', 'enterpriseup' ),
		'section'         => 'enterpriseup_blog_section',
		'settings'        => 'enterpriseup_blog_excerpt_count',
		'type'            => 'number',
		'input_attrs'     => array(
			'min' => 1,
			'max' => 100,
		),
		'active_callback' => 'enterpriseup_is_blog_section_enabled',
	)
);

// Blog Section - Content Type.
$wp_customize->add_setting(
	'enterpriseup_blog_content_type',
	array(
		'default'           => 'post',
		'sanitize_callback' => 'enterpriseup_sanitize_select',
	)
);

$wp_customize->add_control(
	'enterpriseup_blog_content_type',
	array(
		'label'           => esc_html__( 'Select Content Type', 'enterpriseup' ),
		'section'         => 'enterpriseup_blog_section',
		'settings'        => 'enterpriseup_blog_content_type',
		'type'            => 'select',
		'active_callback' => 'enterpriseup_is_blog_section_enabled',
		'choices'         => array(
			'post'     => esc_html__( 'Post', 'enterpriseup' ),
			'category' => esc_html__( 'Category', 'enterpriseup' ),
		),
	)
);

// List out selected number of fields.
$blog_count = get_theme_mod( 'enterpriseup_blog_count', 6 );

for ( $i = 1; $i <= $blog_count; $i++ ) {
	// Blog Section - Select Post.
	$wp_customize->add_setting(
		'enterpriseup_blog_content_post_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'enterpriseup_blog_content_post_' . $i,
		array(
			'label'           => esc_html__( 'Select Post ', 'enterpriseup' ) . $i,
			'section'         => 'enterpriseup_blog_section',
			'settings'        => 'enterpriseup_blog_content_post_' . $i,
			'active_callback' => 'enterpriseup_is_blog_section_and_content_type_post_enabled',
			'type'            => 'select',
			'choices'         => enterpriseup_get_post_choices(),
		)
	);

}

// Blog Section - Select Category.
$wp_customize->add_setting(
	'enterpriseup_blog_content_category',
	array(
		'sanitize_callback' => 'enterpriseup_sanitize_select',
	)
);

$wp_customize->add_control(
	'enterpriseup_blog_content_category',
	array(
		'label'           => esc_html__( 'Select Category', 'enterpriseup' ),
		'section'         => 'enterpriseup_blog_section',
		'settings'        => 'enterpriseup_blog_content_category',
		'active_callback' => 'enterpriseup_is_blog_section_and_content_type_category_enabled',
		'type'            => 'select',
		'choices'         => enterpriseup_get_post_cat_choices(),
	)
);

// Blog Section - Button Label.
$wp_customize->add_setting(
	'enterpriseup_blog_button_label',
	array(
		'default'           => __( 'View All', 'enterpriseup' ),
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'enterpriseup_blog_button_label',
	array(
		'label'           => esc_html__( 'Button Label', 'enterpriseup' ),
		'section'         => 'enterpriseup_blog_section',
		'settings'        => 'enterpriseup_blog_button_label',
		'type'            => 'text',
		'active_callback' => 'enterpriseup_is_blog_section_enabled',
	)
);

// Blog Section - Button Link.
$wp_customize->add_setting(
	'enterpriseup_blog_button_link',
	array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control(
	'enterpriseup_blog_button_link',
	array(
		'label'           => esc_html__( 'Button Link', 'enterpriseup' ),
		'section'         => 'enterpriseup_blog_section',
		'settings'        => 'enterpriseup_blog_button_link',
		'type'            => 'url',
		'active_callback' => 'enterpriseup_is_blog_section_enabled',
	)
);
