<?php
/**
 * Features Section
 *
 * @package EnterpriseUp
 */

$wp_customize->add_section(
	'enterpriseup_features_section',
	array(
		'panel' 	=> 'enterpriseup_front_page_options',
		'title' 	=> esc_html__( 'Features Section', 'enterpriseup' ),
		'priority'	=> 40,
	)
);

// Features Section - Enable Section.
$wp_customize->add_setting(
	'enterpriseup_enable_features_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'enterpriseup_sanitize_switch',
	)
);

$wp_customize->add_control(
	new EnterpriseUp_Toggle_Switch_Custom_Control(
		$wp_customize,
		'enterpriseup_enable_features_section',
		array(
			'label'    => esc_html__( 'Enable Features Section', 'enterpriseup' ),
			'section'  => 'enterpriseup_features_section',
			'settings' => 'enterpriseup_enable_features_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'enterpriseup_enable_features_section',
		array(
			'selector' => '#enterpriseup_features_section .section-link',
			'settings' => 'enterpriseup_enable_features_section',
		)
	);
}

// Features Section - Section Title.
$wp_customize->add_setting(
	'enterpriseup_features_title',
	array(
		'default'           => __( 'Our Features', 'enterpriseup' ),
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'enterpriseup_features_title',
	array(
		'label'           => esc_html__( 'Section Title', 'enterpriseup' ),
		'section'         => 'enterpriseup_features_section',
		'settings'        => 'enterpriseup_features_title',
		'type'            => 'text',
		'active_callback' => 'enterpriseup_is_features_section_enabled',
	)
);

// Features Section - Section Text.
$wp_customize->add_setting(
	'enterpriseup_features_text',
	array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'enterpriseup_features_text',
	array(
		'label'           => esc_html__( 'Section Sub Title', 'enterpriseup' ),
		'section'         => 'enterpriseup_features_section',
		'settings'        => 'enterpriseup_features_text',
		'type'            => 'text',
		'active_callback' => 'enterpriseup_is_features_section_enabled',
	)
);

// CTA Section - Section Image.
$wp_customize->add_setting(
	'enterpriseup_features_image',
	array(
		'sanitize_callback' => 'enterpriseup_sanitize_image',
	)
);

$wp_customize->add_control(
	new WP_Customize_Image_Control(
		$wp_customize,
		'enterpriseup_features_image',
		array(
			'label'           => esc_html__( 'Section Image', 'enterpriseup' ),
			'section'         => 'enterpriseup_features_section',
			'settings'        => 'enterpriseup_features_image',
			'active_callback' => 'enterpriseup_is_features_section_enabled',
		)
	)
);

// Features Section - Content Type.
$wp_customize->add_setting(
	'enterpriseup_features_content_type',
	array(
		'default'           => 'page',
		'sanitize_callback' => 'enterpriseup_sanitize_select',
	)
);

$wp_customize->add_control(
	'enterpriseup_features_content_type',
	array(
		'label'           => esc_html__( 'Select Content Type', 'enterpriseup' ),
		'section'         => 'enterpriseup_features_section',
		'settings'        => 'enterpriseup_features_content_type',
		'type'            => 'select',
		'active_callback' => 'enterpriseup_is_features_section_enabled',
		'choices'         => array(
			'page' => esc_html__( 'Page', 'enterpriseup' ),
			'post' => esc_html__( 'Post', 'enterpriseup' ),
		),
	)
);

for ( $i = 1; $i <= 4; $i++ ) {
	// Features Section - Select Post.
	$wp_customize->add_setting(
		'enterpriseup_features_content_post_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'enterpriseup_features_content_post_' . $i,
		array(
			'label'           => esc_html__( 'Select Post ', 'enterpriseup' ) . $i,
			'section'         => 'enterpriseup_features_section',
			'settings'        => 'enterpriseup_features_content_post_' . $i,
			'active_callback' => 'enterpriseup_is_features_section_and_content_type_post_enabled',
			'type'            => 'select',
			'choices'         => enterpriseup_get_post_choices(),
		)
	);

	// Features Section - Select Page.
	$wp_customize->add_setting(
		'enterpriseup_features_content_page_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'enterpriseup_features_content_page_' . $i,
		array(
			'label'           => esc_html__( 'Select Page ', 'enterpriseup' ) . $i,
			'section'         => 'enterpriseup_features_section',
			'settings'        => 'enterpriseup_features_content_page_' . $i,
			'active_callback' => 'enterpriseup_is_features_section_and_content_type_page_enabled',
			'type'            => 'select',
			'choices'         => enterpriseup_get_page_choices(),
		)
	);

}
