<?php
/**
 * Newsletter Section
 *
 * @package EnterpriseUp
 */

$wp_customize->add_section(
	'enterpriseup_newsletter_section',
	array(
		'panel' 	=> 'enterpriseup_front_page_options',
		'title' 	=> esc_html__( 'Newsletter Section', 'enterpriseup' ),
		'priority'	=> 80,
	)
);

// Newsletter Section - Enable Section.
$wp_customize->add_setting(
	'enterpriseup_enable_newsletter_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'enterpriseup_sanitize_switch',
	)
);

$wp_customize->add_control(
	new EnterpriseUp_Toggle_Switch_Custom_Control(
		$wp_customize,
		'enterpriseup_enable_newsletter_section',
		array(
			'label'    => esc_html__( 'Enable Newsletter Section', 'enterpriseup' ),
			'section'  => 'enterpriseup_newsletter_section',
			'settings' => 'enterpriseup_enable_newsletter_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'enterpriseup_enable_newsletter_section',
		array(
			'selector' => '#enterpriseup_newsletter_section .section-link',
			'settings' => 'enterpriseup_enable_newsletter_section',
		)
	);
}

// Newsletter Section - Section Title.
$wp_customize->add_setting(
	'enterpriseup_newsletter_title',
	array(
		'default'           => __( 'Join Our Mailing List', 'enterpriseup' ),
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'enterpriseup_newsletter_title',
	array(
		'label'           => esc_html__( 'Section Title', 'enterpriseup' ),
		'section'         => 'enterpriseup_newsletter_section',
		'settings'        => 'enterpriseup_newsletter_title',
		'type'            => 'text',
		'active_callback' => 'enterpriseup_is_newsletter_section_enabled',
	)
);

// Newsletter Section - Newsletter Content.
$wp_customize->add_setting(
	'enterpriseup_newsletter_content',
	array(
		'default'           => esc_html__( 'Sign up to our newsletter.', 'enterpriseup' ),
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'enterpriseup_newsletter_content',
	array(
		'label'           => esc_html__( 'Content', 'enterpriseup' ),
		'section'         => 'enterpriseup_newsletter_section',
		'settings'        => 'enterpriseup_newsletter_content',
		'type'            => 'text',
		'active_callback' => 'enterpriseup_is_newsletter_section_enabled',
	)
);

// Newsletter Section - Background Color.
$default_color = enterpriseup_get_default_color();
$wp_customize->add_setting(
	'enterpriseup_newsletter_background_color',
	array(
		'default'           => $default_color['secondary'],
		'sanitize_callback' => 'sanitize_hex_color',
	)
);

$wp_customize->add_control(
	new WP_Customize_Color_Control(
		$wp_customize,
		'enterpriseup_newsletter_background_color',
		array(
			'label'           => __( 'Background Color', 'enterpriseup' ),
			'section'         => 'enterpriseup_newsletter_section',
			'settings'        => 'enterpriseup_newsletter_background_color',
			'active_callback' => 'enterpriseup_is_newsletter_section_enabled',
		)
	)
);

// Newsletter Section - Background Image.
$wp_customize->add_setting(
	'enterpriseup_newsletter_background_image',
	array(
		'sanitize_callback' => 'enterpriseup_sanitize_image',
	)
);

$wp_customize->add_control(
	new WP_Customize_Image_Control(
		$wp_customize,
		'enterpriseup_newsletter_background_image',
		array(
			'label'           => esc_html__( 'Background Image', 'enterpriseup' ),
			'description'     => esc_html__( 'Background color will be replaced by image.', 'enterpriseup' ),
			'section'         => 'enterpriseup_newsletter_section',
			'settings'        => 'enterpriseup_newsletter_background_image',
			'active_callback' => 'enterpriseup_is_newsletter_section_enabled',
		)
	)
);
