<?php
/**
 * Team Section
 *
 * @package EnterpriseUp
 */

$wp_customize->add_section(
	'enterpriseup_team_section',
	array(
		'panel' 	=> 'enterpriseup_front_page_options',
		'title' 	=> esc_html__( 'Team Section', 'enterpriseup' ),
		'priority'	=> 60,
	)
);

// Team Section - Enable Section.
$wp_customize->add_setting(
	'enterpriseup_enable_team_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'enterpriseup_sanitize_switch',
	)
);

$wp_customize->add_control(
	new EnterpriseUp_Toggle_Switch_Custom_Control(
		$wp_customize,
		'enterpriseup_enable_team_section',
		array(
			'label'    => esc_html__( 'Enable Team Section', 'enterpriseup' ),
			'section'  => 'enterpriseup_team_section',
			'settings' => 'enterpriseup_enable_team_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'enterpriseup_enable_team_section',
		array(
			'selector' => '#enterpriseup_team_section .section-link',
			'settings' => 'enterpriseup_enable_team_section',
		)
	);
}

// Team Section - Section Title.
$wp_customize->add_setting(
	'enterpriseup_team_section_title',
	array(
		'default'           => __( 'Our Team', 'enterpriseup' ),
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'enterpriseup_team_section_title',
	array(
		'label'           => esc_html__( 'Section Title', 'enterpriseup' ),
		'section'         => 'enterpriseup_team_section',
		'settings'        => 'enterpriseup_team_section_title',
		'type'            => 'text',
		'active_callback' => 'enterpriseup_is_team_section_enabled',
	)
);

// Team Section - Section Text.
$wp_customize->add_setting(
	'enterpriseup_team_section_text',
	array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'enterpriseup_team_section_text',
	array(
		'label'           => esc_html__( 'Section Text', 'enterpriseup' ),
		'section'         => 'enterpriseup_team_section',
		'settings'        => 'enterpriseup_team_section_text',
		'type'            => 'text',
		'active_callback' => 'enterpriseup_is_team_section_enabled',
	)
);

// Team Section - Content Type.
$wp_customize->add_setting(
	'enterpriseup_team_content_type',
	array(
		'default'           => 'post',
		'sanitize_callback' => 'enterpriseup_sanitize_select',
	)
);

$wp_customize->add_control(
	'enterpriseup_team_content_type',
	array(
		'label'           => esc_html__( 'Select Content Type', 'enterpriseup' ),
		'section'         => 'enterpriseup_team_section',
		'settings'        => 'enterpriseup_team_content_type',
		'type'            => 'select',
		'active_callback' => 'enterpriseup_is_team_section_enabled',
		'choices'         => array(
			'page' => esc_html__( 'Page', 'enterpriseup' ),
			'post' => esc_html__( 'Post', 'enterpriseup' ),
		),
	)
);

for ( $i = 1; $i <= 3; $i++ ) {
	// Team Section - Select Post.
	$wp_customize->add_setting(
		'enterpriseup_team_content_post_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'enterpriseup_team_content_post_' . $i,
		array(
			/* translators: %d: count. */
			'label'           => sprintf( esc_html__( 'Select Post %d', 'enterpriseup' ), $i ),
			'section'         => 'enterpriseup_team_section',
			'settings'        => 'enterpriseup_team_content_post_' . $i,
			'active_callback' => 'enterpriseup_is_team_section_and_content_type_post_enabled',
			'type'            => 'select',
			'choices'         => enterpriseup_get_post_choices(),
		)
	);

	// Team Section - Select Page.
	$wp_customize->add_setting(
		'enterpriseup_team_content_page_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'enterpriseup_team_content_page_' . $i,
		array(
			/* translators: %d: count. */
			'label'           => sprintf( esc_html__( 'Select Page %d', 'enterpriseup' ), $i ),
			'section'         => 'enterpriseup_team_section',
			'settings'        => 'enterpriseup_team_content_page_' . $i,
			'active_callback' => 'enterpriseup_is_team_section_and_content_type_page_enabled',
			'type'            => 'select',
			'choices'         => enterpriseup_get_page_choices(),
		)
	);

	// Team Section - Designation.
	$wp_customize->add_setting(
		'enterpriseup_team_position_' . $i,
		array(
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'enterpriseup_team_position_' . $i,
		array(
			/* translators: %d: count. */
			'label'           => sprintf( esc_html__( 'Designation %d', 'enterpriseup' ), $i ),
			'section'         => 'enterpriseup_team_section',
			'settings'        => 'enterpriseup_team_position_' . $i,
			'active_callback' => 'enterpriseup_is_team_section_enabled',
		)
	);

	// Team Section - Social Links.
	$wp_customize->add_setting(
		'enterpriseup_team_social_links_' . $i,
		array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		)
	);
	$wp_customize->add_control(
		new EnterpriseUp_Sortable_Repeater_Custom_Control(
			$wp_customize,
			'enterpriseup_team_social_links_' . $i,
			array(
				/* translators: %d: count. */
				'label'           => sprintf( esc_html__( 'Social Links %d', 'enterpriseup' ), $i ),
				'section'         => 'enterpriseup_team_section',
				'button_labels'   => array(
					'add' => __( 'Add', 'enterpriseup' ),
				),
				'active_callback' => 'enterpriseup_is_team_section_enabled',
			)
		)
	);
}

// Team Section - Button Label.
$wp_customize->add_setting(
	'enterpriseup_team_button_label',
	array(
		'default'           => __( 'View All', 'enterpriseup' ),
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'enterpriseup_team_button_label',
	array(
		'label'           => esc_html__( 'Button Label', 'enterpriseup' ),
		'section'         => 'enterpriseup_team_section',
		'settings'        => 'enterpriseup_team_button_label',
		'type'            => 'text',
		'active_callback' => 'enterpriseup_is_team_section_enabled',
	)
);

// Team Section - Button Link.
$wp_customize->add_setting(
	'enterpriseup_team_button_link',
	array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control(
	'enterpriseup_team_button_link',
	array(
		'label'           => esc_html__( 'Button Link', 'enterpriseup' ),
		'section'         => 'enterpriseup_team_section',
		'settings'        => 'enterpriseup_team_button_link',
		'type'            => 'url',
		'active_callback' => 'enterpriseup_is_team_section_enabled',
	)
);
