<?php

if ( ! get_theme_mod( 'enterpriseup_enable_blog_section', false ) ) {
	return;
}

$content_ids   = array();
$content_count = get_theme_mod( 'enterpriseup_blog_count', 6 );
$content_type  = get_theme_mod( 'enterpriseup_blog_content_type', 'post' );

if ( $content_type == 'post' ) {

	for ( $i = 1; $i <= $content_count; $i++ ) {
		$content_ids[] = get_theme_mod( 'enterpriseup_blog_content_post_' . $i );
	}

	$args = array(
		'post_type'           => 'post',
		'post__in'            => array_filter( $content_ids ),
		'orderby'             => 'post__in',
		'posts_per_page'      => absint( $content_count ),
		'ignore_sticky_posts' => true,
	);

} else {
	$cat_content_id = get_theme_mod( 'enterpriseup_blog_content_category' );
	$args           = array(
		'cat'            => $cat_content_id,
		'posts_per_page' => absint( $content_count ),
	);
}

$args = apply_filters( 'enterpriseup_blog_section_args', $args );

enterpriseup_render_blog_section( $args );

/**
 * Render Blog Section.
 */
function enterpriseup_render_blog_section( $args ) {
	$section_title = get_theme_mod( 'enterpriseup_blog_title', __( 'Latest News', 'enterpriseup' ) );
	$section_text  = get_theme_mod( 'enterpriseup_blog_text' );
	$button_label  = get_theme_mod( 'enterpriseup_blog_button_label', __( 'View All', 'enterpriseup' ) );
	$button_link   = get_theme_mod( 'enterpriseup_blog_button_link' );
	$button_link   = ! empty( $button_link ) ? $button_link : '#';

	$query = new WP_Query( $args );
	if ( $query->have_posts() ) :
		?>
		<section id="enterpriseup_blog_section" class="enterpriseup-frontpage-section enterpriseup-blog-section enterpriseup-grey-background enterpriseup-carousel style-1">
			<?php
			if ( is_customize_preview() ) :
				enterpriseup_section_link( 'enterpriseup_blog_section' );
			endif;
			?>
			<div class="ascendoor-wrapper">
				<?php if ( ! empty( $section_title || $section_text ) ) : ?>
					<div class="section-header-subtitle">
						<h3 class="section-title"><?php echo esc_html( $section_title ); ?></h3>
						<p class="section-subtitle"><?php echo esc_html( $section_text ); ?></p>
					</div>
				<?php endif; ?>
			</div>
			<div class="enterpriseup-section-body">
				<div class="enterpriseup-blog-section-wrapper enterpriseup-news">
					<?php
					while ( $query->have_posts() ) :
						$query->the_post();
						?>
						<div class="enterpriseup-blog-single">
							<div class="enterpriseup-blog-img">
								<a href="<?php the_permalink(); ?>">
									<?php the_post_thumbnail( 'large' ); ?>
								</a>
							</div>
							<div class="enterpriseup-detail">
								<div class="shop-blog-category">
									<?php echo get_the_category_list( ', ', '', get_the_ID() ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
								</div>
								<h3 class="enterpriseup-blog-title">
									<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
								</h3>
								<div class="enterpriseup-meta">
									<?php echo get_the_date(); ?>
								</div>
								<div class="enterpriseup-description">
									<?php echo wp_kses_post( wp_trim_words( get_the_content(), get_theme_mod( 'enterpriseup_blog_excerpt_count', 20 ) ) ); ?>
								</div>
							</div>
						</div>
						<?php
					endwhile;
					wp_reset_postdata();
					?>
				</div>
				<?php if ( ! empty( $button_label ) ) : ?>
					<div class="enterpriseup-blog-view-all enterpriseup-button">
						<a href="<?php echo esc_url( $button_link ); ?>"><?php echo esc_html( $button_label ); ?></a>
					</div>
				<?php endif; ?>
			</div>
		</section>
		<?php
	endif;
}
