<?php

if ( ! get_theme_mod( 'enterpriseup_enable_service_section', false ) ) {
	return;
}

$content_ids  = array();
$content_type = get_theme_mod( 'enterpriseup_service_content_type', 'page' );

if ( in_array( $content_type, array( 'post', 'page' ) ) ) {

	for ( $i = 1; $i <= 4; $i++ ) {
		$content_ids[] = get_theme_mod( 'enterpriseup_service_content_' . $content_type . '_' . $i );
	}

	$args = array(
		'post_type'           => $content_type,
		'post__in'            => array_filter( $content_ids ),
		'orderby'             => 'post__in',
		'posts_per_page'      => absint( 4 ),
		'ignore_sticky_posts' => true,
	);

}

$args = apply_filters( 'enterpriseup_service_section_args', $args );

enterpriseup_render_service_section( $args );

/**
 * Render Service Section.
 */
function enterpriseup_render_service_section( $args ) {
	$section_title        = get_theme_mod( 'enterpriseup_service_title', __( 'Our Services', 'enterpriseup' ) );
	$section_description  = get_theme_mod( 'enterpriseup_service_short_description' );
	$service_button_label = get_theme_mod( 'enterpriseup_service_button_label', __( 'View All Services', 'enterpriseup' ) );
	$service_button_link  = get_theme_mod( 'enterpriseup_service_button_link' );
	$service_button_link  = ! empty( $service_button_link ) ? $service_button_link : '#';
	$service_link_text    = get_theme_mod( 'enterpriseup_excerpt_more_text', __( 'Read More', 'enterpriseup' ) );

	$query = new WP_Query( $args );
	?>
	<section id="enterpriseup_service_section" class="enterpriseup-frontpage-section enterpriseup-our-services-section enterpriseup-secondary1-background style-1">
		<?php
		if ( is_customize_preview() ) :
			enterpriseup_section_link( 'enterpriseup_service_section' );
		endif;
		?>
		<div class="ascendoor-wrapper">
			<div class="enterpriseup-section-half">
				<div class="section-header-subtitle section-header-subtitle-left">
					<h3 class="section-title"><?php echo esc_html( $section_title ); ?></h3>
					<p class="section-subtitle"><?php echo esc_html( $section_description ); ?></p>
					<?php if ( ! empty( $service_button_label ) ) { ?>
						<div class="enterpriseup-button enterpriseup-button-alternate">
							<a href="<?php echo esc_url( $service_button_link ); ?>"><?php echo esc_html( $service_button_label ); ?></a>
						</div>
					<?php } ?>
				</div>
				<?php if ( $query->have_posts() ) : ?>
					<div class="enterpriseup-section-body">
						<div class="enterpriseup-our-services-section-wrapper">
							<?php
							while ( $query->have_posts() ) :
								$query->the_post();
								?>
								<div class="enterpriseup-service-single">
									<div class="enterpriseup-service-img">
										<a href="<?php the_permalink(); ?>">
											<?php the_post_thumbnail(); ?>
										</a>
									</div>
									<div class="enterpriseup-service-detail">
										<h3 class="service-title">
											<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
										</h3>
										<?php the_excerpt(); ?>
										<?php if ( ! empty( $service_link_text ) ) : ?>
											<div class="enterpriseup-button enterpriseup-button-noborder-noalternate">
												<a href="<?php the_permalink(); ?>"><?php echo esc_html( $service_link_text ); ?></a>
											</div>
										<?php endif; ?>
									</div>
								</div>
								<?php
							endwhile;
							wp_reset_postdata();
							?>
						</div>
					</div>
				<?php endif; ?>
			</div>
		</div>
	</section>
	<?php
}
